and

$$F U ∆ ( δ | 1 , z ) =      1 + inf y ∈ R { min( F 1 ( y | 1 , z ) - F 0 ( y - δ | 1 , z )) , 0 } , for δ ≥ m C ( z ) , 0 , for δ < m C ( z ) ,$$

$$F L ∆ ( δ | 0 , z ) =      1 , for δ ≥ m C ( z ) , sup y ∈ R max { F 1 ( y ) - F 0 ( y - δ ) , 0 } , for δ < m C ( z ) ,$$

$$F U ∆ ( δ | 0 , z ) =      1 , for δ ≥ m C ( z ) , 1 + inf { b k } ∞ k = -∞ { min( F 1 ( b k +1 + m C ( z )) - F 0 ( b k )) , 0 } , for δ < m C ( z ) ,$$

with

$$b k + δ - m C ( z ) ≤ b k +1 ≤ b k .$$

Based on the bounds on F ∆ ( δ | d, z ), the identification region of the DTE can be obtained by intersection bounds as presented in Chernozhukov et al. (2013). 12

Corollary 3 The DTE in the extended Roy model is bounded as follows:

$$F L ∆ ( δ ) ≤ F ∆ ( δ ) ≤ F U ∆ ( δ ) ,$$

where

$$F L ∆ ( δ ) = sup z [ F L ∆ ( δ | 1 , z ) p ( z ) + F L ∆ ( δ | 0 , z ) (1 - p ( z )) ] , F U ∆ ( δ ) = inf z [ F U ∆ ( δ | 1 , z ) p ( z ) + F U ∆ ( δ | 0 , z ) (1 - p ( z )) ] .$$

### 4 Numerical Illustration

This section provides numerical illustration to assess the informativeness of my new bounds. Since my sharp bounds on the DTE under support restrictions are written with respect to given marginal distribution functions F 0 and F 1 , the tightness of the bounds is affected by the properties of these marginal distributions. I report the results of numerical examples to clarify the association between the identifying power of my bounds and the marginal distribution functions F 0 and F 1 . I focus on MTR, which is one of the most widely applicable support restrictions in economics.

My numerical examples use the following data generating process for the potential outcomes equation:

12 The bounds on the DTE are sharp without any other additional assumption. Park (2013) showed that the DTE can be point-identified in the extended Roy model under continuous IV with the large support and a restriction on the function m c .

28